---@type ChadrcConfig
local M = {}

--[[ local stbufnr = function()
	return vim.api.nvim_win_get_buf(vim.g.statusline_winid or 0)
end ]]

M.ui = {
	transparency = true,
	theme = "catppuccin",
	statusline = {
		--[[ theme = "default", -- default/vscode/vscode_colored/minimal ]]
		-- default/round/block/arrow (separators work only for "default" statusline theme;
		-- round and block will work for the minimal theme only)
		separator_style = "round",
		modules = {
			lsp = "",
			--[[ lsp = function()
				if rawget(vim, "lsp") then
					for _, client in ipairs(vim.lsp.get_active_clients()) do
						if client.attached_buffers[stbufnr()] and client.name ~= "null-ls" then
							return (vim.o.columns > 100 and "   " .. client.name .. " ") or "   LSP "
						end
					end
				end
				return ""
			end, ]]
		},
	},

	tabufline = {
		enabled = true,
		lazyload = true,
		modules = {}
	},

	telescope = { style = "borderless" }, -- borderless / bordered

	nvdash = {
		load_on_startup = true,

		header = {
			"⣇⣿⠘⣿⣿⣿⡿⡿⣟⣟⢟⢟⢝⠵⡝⣿⡿⢂⣼⣿⣷⣌⠩⡫⡻⣝⠹⢿⣿⣷",
			"⡆⣿⣆⠱⣝⡵⣝⢅⠙⣿⢕⢕⢕⢕⢝⣥⢒⠅⣿⣿⣿⡿⣳⣌⠪⡪⣡⢑⢝⣇",
			"⡆⣿⣿⣦⠹⣳⣳⣕⢅⠈⢗⢕⢕⢕⢕⢕⢈⢆⠟⠋⠉⠁⠉⠉⠁⠈⠼⢐⢕⢽",
			"⡗⢰⣶⣶⣦⣝⢝⢕⢕⠅⡆⢕⢕⢕⢕⢕⣴⠏⣠⡶⠛⡉⡉⡛⢶⣦⡀⠐⣕⢕",
			"⡝⡄⢻⢟⣿⣿⣷⣕⣕⣅⣿⣔⣕⣵⣵⣿⣿⢠⣿⢠⣮⡈⣌⠨⠅⠹⣷⡀⢱⢕",
			"⡝⡵⠟⠈⢀⣀⣀⡀⠉⢿⣿⣿⣿⣿⣿⣿⣿⣼⣿⢈⡋⠴⢿⡟⣡⡇⣿⡇⡀⢕",
			"⡝⠁⣠⣾⠟⡉⡉⡉⠻⣦⣻⣿⣿⣿⣿⣿⣿⣿⣿⣧⠸⣿⣦⣥⣿⡇⡿⣰⢗⢄",
			"⠁⢰⣿⡏⣴⣌⠈⣌⠡⠈⢻⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣬⣉⣉⣁⣄⢖⢕⢕⢕",
			"⡀⢻⣿⡇⢙⠁⠴⢿⡟⣡⡆⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣷⣵⣵⣿",
			"⡻⣄⣻⣿⣌⠘⢿⣷⣥⣿⠇⣿⣿⣿⣿⣿⣿⠛⠻⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿",
			"⣷⢄⠻⣿⣟⠿⠦⠍⠉⣡⣾⣿⣿⣿⣿⣿⣿⢸⣿⣦⠙⣿⣿⣿⣿⣿⣿⣿⣿⠟",
			"⡕⡑⣑⣈⣻⢗⢟⢞⢝⣻⣿⣿⣿⣿⣿⣿⣿⠸⣿⠿⠃⣿⣿⣿⣿⣿⣿⡿⠁⣠",
			"⡝⡵⡈⢟⢕⢕⢕⢕⣵⣿⣿⣿⣿⣿⣿⣿⣿⣿⣶⣶⣿⣿⣿⣿⣿⠿⠋⣀⣈⠙",
			"⡝⡵⡕⡀⠑⠳⠿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⠿⠛⢉⡠⡲⡫⡪⡪⡣",
		},

		extended_integrations = {
			"dap",
			"hop",
			"rainbowdelimiters",
			"codeactionmenu",
			"todo",
			"trouble",
			"notify",
		},

		buttons = {
			{ "  Find File", "Spc f f", "Telescope find_files" },
			{ "󰈚  Recent Files", "Spc f o", "Telescope oldfiles" },
			{ "󰈭  Find Word", "Spc f w", "Telescope live_grep" },
			{ "  Bookmarks", "Spc m a", "Telescope marks" },
			{ "  Themes", "Spc t h", "Telescope themes" },
			{ "  Mappings", "Spc c h", "NvCheatsheet" },
		},
	},

	---@type Base46HLGroupsList
	hl_override = {
		NvDashAscii = { bg = "NONE", fg = "#85c0dc" },
		NvDashButtons = { bg = "NONE", fg = "#b4befe" },
		CursorLine = {
			bg = "#313244",
		},
		Search = {
			--[[ bg = "#89dceb", ]]
			bg = "#f5c2e7",
		},
	},

	-- cmp themeing
	cmp = {
		icons = true,
		lspkind_text = true,
		style = "default",         -- default/flat_light/flat_dark/atom/atom_colored
		border_color = "grey_fg",  -- only applicable for "default" style, use color names from base30 variables
		selected_item_bg = "simple", -- colored / simple
	},

	lsp = { signature = true },

	--[[ term = {
		hl = "Normal:term,WinSeparator:WinSeparator",
		sizes = { sp = 0.3, vsp = 0.2 },
		float_opts = {
			relative = "editor",
			row = 0.04,
			col = 0.06,
			width = 0.85,
			height = 0.85,
			border = "rounded",
		},
	}, ]]
}

return M
